## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## -----------------------------------------------------------------------------
# Load the tcltk package
library(tcltk)


## -----------------------------------------------------------------------------
# Load the following packages.
library(tcltk2)
library(terra)
library(sara4r)

## -----------------------------------------------------------------------------
sara4r()

